from _typeshed import Incomplete
from typing import Final, final

import gdb

class Disassembler:
    def __init__(self, name: str) -> None: ...
    def __call__(self, info): ...

class DisassembleInfo:
    address: Incomplete
    architecture: Incomplete
    progspace: Incomplete
    def __init__(self, /, *args, **kwargs) -> None: ...
    def address_part(self, address) -> DisassemblerAddressPart: ...
    def is_valid(self) -> bool: ...
    def read_memory(self, len, offset: int = 0): ...
    def text_part(self, string, style) -> DisassemblerTextPart: ...

class DisassemblerPart:
    def __init__(self, /, *args, **kwargs) -> None: ...

@final
class DisassemblerAddressPart(DisassemblerPart):
    address: Incomplete
    string: str

@final
class DisassemblerTextPart(DisassemblerPart):
    string: str
    style: Incomplete

@final
class DisassemblerResult:
    def __init__(self, /, *args, **kwargs) -> None: ...
    length: Incomplete
    parts: Incomplete
    string: str

STYLE_TEXT: Final = 0
STYLE_MNEMONIC: Final = 1
STYLE_SUB_MNEMONIC: Final = 2
STYLE_ASSEMBLER_DIRECTIVE: Final = 3
STYLE_REGISTER: Final = 4
STYLE_IMMEDIATE: Final = 5
STYLE_ADDRESS: Final = 6
STYLE_ADDRESS_OFFSET: Final = 7
STYLE_SYMBOL: Final = 8
STYLE_COMMENT_START: Final = 9

def builtin_disassemble(INFO: DisassembleInfo, MEMORY_SOURCE: Incomplete | None = None) -> None: ...

class maint_info_py_disassemblers_cmd(gdb.Command):
    def __init__(self) -> None: ...
    def invoke(self, args, from_tty): ...

def register_disassembler(disassembler: type[Disassembler], architecture: str | None = None): ...



import gdb
from gdb import Frame, UnwindInfo

class FrameId:
    def __init__(self, sp: gdb.Value | int, pc: gdb.Value | int, special: gdb.Value | int | None = None) -> None: ...
    @property
    def pc(self) -> gdb.Value | int: ...
    @property
    def sp(self) -> gdb.Value | int: ...
    @property
    def special(self) -> gdb.Value | int | None: ...

class Unwinder:
    @property
    def name(self) -> str: ...
    enabled: bool

    def __init__(self, name: str) -> None: ...
    def __call__(self, pending_frame: Frame) -> UnwindInfo | None: ...

def register_unwinder(locus: gdb.Objfile | gdb.Progspace | None, unwinder: Unwinder, replace: bool = ...) -> None: ...



from typing import Any

class Server:
    def __init__(self, in_stream, out_stream, child_stream) -> None: ...
    def main_loop(self) -> None: ...
    def send_event(self, event: str, body: Any | None = None) -> None: ...  # body is an arbitrary object
    def send_event_later(self, event: str, body: Any | None = None) -> None: ...  # body is an arbitrary object
    def shutdown(self) -> None: ...

def pre_command_loop() -> None: ...
def run() -> None: ...

session_started: bool



from _typeshed import Incomplete

import gdb

class MissingDebugHandler:
    @property
    def name(self) -> str: ...
    enabled: bool
    def __init__(self, name: str) -> None: ...
    def __call__(self, objfile: gdb.Objfile) -> bool | str | None: ...

def register_handler(locus: Incomplete | None, handler: MissingDebugHandler, replace: bool = False) -> None: ...



import gdb

cont: gdb.EventRegistry[gdb.ContinueEvent]
exited: gdb.EventRegistry[gdb.ExitedEvent]
thread_exited: gdb.EventRegistry[gdb.ThreadExitedEvent]
stop: gdb.EventRegistry[gdb.StopEvent]
new_objfile: gdb.EventRegistry[gdb.NewObjFileEvent]
free_objfile: gdb.EventRegistry[gdb.FreeObjFileEvent]
clear_objfiles: gdb.EventRegistry[gdb.ClearObjFilesEvent]
new_progspace: gdb.EventRegistry[gdb.NewProgspaceEvent]
free_progspace: gdb.EventRegistry[gdb.FreeProgspaceEvent]
inferior_call: gdb.EventRegistry[gdb._InferiorCallEvent]
memory_changed: gdb.EventRegistry[gdb.MemoryChangedEvent]
register_changed: gdb.EventRegistry[gdb.RegisterChangedEvent]
breakpoint_created: gdb.EventRegistry[gdb.Breakpoint]
breakpoint_modified: gdb.EventRegistry[gdb.Breakpoint]
breakpoint_deleted: gdb.EventRegistry[gdb.Breakpoint]
before_prompt: gdb.EventRegistry[None]
new_inferior: gdb.EventRegistry[gdb.NewInferiorEvent]
inferior_deleted: gdb.EventRegistry[gdb.InferiorDeletedEvent]
new_thread: gdb.EventRegistry[gdb.NewThreadEvent]
gdb_exiting: gdb.EventRegistry[gdb.GdbExitingEvent]
connection_removed: gdb.EventRegistry[gdb.ConnectionEvent]
executable_changed: gdb.EventRegistry[gdb.ExecutableChangedEvent]



from setuptools import setup

name = "types-gdb"
description = "Typing stubs for gdb"
long_description = '''
## Typing stubs for gdb

This is a [PEP 561](https://peps.python.org/pep-0561/)
type stub package for the [`gdb`](https://sourceware.org/git/gitweb.cgi?p=binutils-gdb.git;a=tree) package.
It can be used by type-checking tools like
[mypy](https://github.com/python/mypy/),
[pyright](https://github.com/microsoft/pyright),
[pytype](https://github.com/google/pytype/),
PyCharm, etc. to check code that uses
`gdb`.

This version of `types-gdb` aims to provide accurate annotations
for `gdb==15.0.*`.
The source for this package can be found at
https://github.com/python/typeshed/tree/main/stubs/gdb. All fixes for
types and metadata should be contributed there.

Type hints for GDB's [Python API](https://sourceware.org/gdb/onlinedocs/gdb/Python-API.html). Note that this API is available only when running Python scripts under GDB: it is not possible to install the `gdb` package separately, for instance using `pip`.

See https://github.com/python/typeshed/blob/main/README.md for more details.
This package was generated from typeshed commit
[`a871efd90ca2734b3341dde98cffab66f3e08cee`](https://github.com/python/typeshed/commit/a871efd90ca2734b3341dde98cffab66f3e08cee) and was tested
with mypy 1.11.2, pyright 1.1.383, and
pytype 2024.10.11.
'''.lstrip()

setup(name=name,
      version="15.0.0.20241015",
      description=description,
      long_description=long_description,
      long_description_content_type="text/markdown",
      url="https://github.com/python/typeshed",
      project_urls={
          "GitHub": "https://github.com/python/typeshed",
          "Changes": "https://github.com/typeshed-internal/stub_uploader/blob/main/data/changelogs/gdb.md",
          "Issue tracker": "https://github.com/python/typeshed/issues",
          "Chat": "https://gitter.im/python/typing",
      },
      install_requires=[],
      packages=['gdb-stubs'],
      package_data={'gdb-stubs': ['FrameDecorator.pyi', 'FrameIterator.pyi', '__init__.pyi', 'dap/__init__.pyi', 'dap/breakpoint.pyi', 'dap/bt.pyi', 'dap/disassemble.pyi', 'dap/evaluate.pyi', 'dap/events.pyi', 'dap/frames.pyi', 'dap/io.pyi', 'dap/launch.pyi', 'dap/locations.pyi', 'dap/memory.pyi', 'dap/modules.pyi', 'dap/next.pyi', 'dap/pause.pyi', 'dap/scopes.pyi', 'dap/server.pyi', 'dap/sources.pyi', 'dap/startup.pyi', 'dap/state.pyi', 'dap/threads.pyi', 'dap/typecheck.pyi', 'dap/varref.pyi', 'disassembler.pyi', 'events.pyi', 'missing_debug.pyi', 'printing.pyi', 'prompt.pyi', 'types.pyi', 'unwinder.pyi', 'xmethod.pyi', 'METADATA.toml', 'py.typed']},
      license="Apache-2.0",
      python_requires=">=3.8",
      classifiers=[
          "License :: OSI Approved :: Apache Software License",
          "Programming Language :: Python :: 3",
          "Typing :: Stubs Only",
      ]
)
